@@ -102,11 +102,11 @@ def limit(method, timeout):
     """ 这里不使用func_timeout， 是因为funct_timeout的函数内部如果启动新的线程，会导致Python进程最后无法退出的问题"""
     def f(*args):
         @jpype.JImplements(jpype.java.util.concurrent.Callable)
-        class g:
+        class ClsJLimit:
             @jpype.JOverride
             def call(self):
                 return method(*args)
-        future = jpype.java.util.concurrent.FutureTask(g())
+        future = jpype.java.util.concurrent.FutureTask(ClsJLimit())
         jpype.java.lang.Thread(future).start()
         try:
             timeunit = jpype.java.util.concurrent.TimeUnit.SECONDS
@@ -650,6 +650,8 @@ class Cursor(object):
                 converter = _DEFAULT_CONVERTERS["YEAR"]
             elif m_ColumnTypeName in ['timestamptz']:       # PG数据类型
                 converter = _DEFAULT_CONVERTERS["TIMESTAMP_WITH_TIMEZONE"]
+            elif m_ColumnClassName in ['java.sql.SQLXML']:       # SQLXML
+                converter = _DEFAULT_CONVERTERS["VARCHAR"]
             else:
                 if sqltype in self._converters.keys():
                     converter = self._converters.get(sqltype)
@@ -862,6 +864,8 @@ def _pyobj_to_javaobj(p_pyobj):
 
 
 def _javaobj_to_pyobj(p_javaobj, p_objColumnSQLType=None):
+    if p_javaobj is None:
+        return None
     if type(p_javaobj) == str:
         return p_javaobj
     m_TypeName = str(p_javaobj.getClass().getTypeName())
@@ -934,6 +938,10 @@ def _javaobj_to_pyobj(p_javaobj, p_objColumnSQLType=None):
         m_LargeObject.setObjectLength(m_Length)
         m_LargeObject.setObject(p_javaobj)
         return m_LargeObject
+    elif m_TypeName.upper() in ['ORACLE.SQL.ROWID']:
+        return p_javaobj.toString()
+    elif m_TypeName.upper() in ['ORACLE.XDB.XMLTYPE']:
+        return p_javaobj.getString()
     else:
         raise SQLCliJDBCException("SQLCLI-00000: Unknown java class type [" + m_TypeName + "] in _javaobj_to_pyobj")
 
@@ -972,11 +980,15 @@ def _java_to_py_timestampwithtimezone(conn, rs, col, p_objColumnSQLType=None):
     elif m_TypeName in ('oracle.sql.TIMESTAMPTZ', 'oracle.sql.TIMESTAMPLTZ'):
         java_val = java_val.offsetDateTimeValue(conn)
         ld = java_val.toLocalDateTime()
-        d = datetime.datetime.strptime(str(ld.getYear()).zfill(4) + "-" + str(ld.getMonthValue()).zfill(2) + "-" +
-                                       str(ld.getDayOfMonth()).zfill(2) + " " + str(ld.getHour()).zfill(2) + ":" +
-                                       str(ld.getMinute()).zfill(2) + ":" + str(ld.getSecond()).zfill(2) + " " +
-                                       str(ld.getNano() // 1000) + " " + java_val.getOffset().getId(),
-                                       "%Y-%m-%d %H:%M:%S %f %z")
+        try:
+            d = datetime.datetime.strptime(str(ld.getYear()).zfill(4) + "-" + str(ld.getMonthValue()).zfill(2) + "-" +
+                                           str(ld.getDayOfMonth()).zfill(2) + " " + str(ld.getHour()).zfill(2) + ":" +
+                                           str(ld.getMinute()).zfill(2) + ":" + str(ld.getSecond()).zfill(2) + " " +
+                                           str(ld.getNano() // 1000) + " " + java_val.getOffset().getId(),
+                                           "%Y-%m-%d %H:%M:%S %f %z")
+        except ValueError:
+            d = str(java_val.format(
+                jpype.java.time.format.DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss.SSSSSS Z")))
         return d
     elif m_TypeName in 'org.h2.api.TimestampWithTimeZone':
         java_val = rs.getObject(col, jpype.JClass("java.time.OffsetDateTime"))
@@ -1095,4 +1107,5 @@ _DEFAULT_CONVERTERS = {
     'YEAR':                             _to_year,
     'BINARY':                           _to_binary,
     'BFILE':                            _to_bfile,
+    'ROWID':                            _java_to_py
 }
